Method: Camdict::Sentence#usage
- Defined in:
- lib/camdict/sentence.rb
#usage ⇒ Object (readonly)
Get the grammar code or usage in this sentence. It means how the word is used in this sentence. For example, a grammar code for the word - ‘somewhere’ is “+to infinitive”. I’m looking for somewhere to eat.
12 13 14 |
# File 'lib/camdict/sentence.rb', line 12 def usage @usage end |